NAME

Langertha::Knarr::CLI::Cmd::Start - Start the Knarr proxy server

VERSION

version 0.004

DESCRIPTION

Implements the knarr start command. Loads the config file, validates it, and starts the Mojolicious server. Exits with an error if the config file is not found or fails validation.

See knarr for the full option reference and Langertha::Knarr for the configuration file format.

SEE ALSO

SUPPORT

Issues

Please report bugs and feature requests on GitHub at https://github.com/Getty/langertha-knarr/issues.

CONTRIBUTING

Contributions are welcome! Please fork the repository and submit a pull request.

AUTHOR

Torsten Raudssus <torsten@raudssus.de> https://raudssus.de/

COPYRIGHT AND LICENSE

This software is copyright (c) 2026 by Torsten Raudssus.

This is free software; you can redistribute it and/or modify it under the same terms as the Perl 5 programming language system itself.