NAME

Langertha::Knarr::Proxy::OpenAI - OpenAI API format proxy handler

VERSION

version 0.004

DESCRIPTION

Handles the OpenAI Chat Completions API format for Langertha::Knarr.

Routes handled:

  • POST /v1/chat/completions — chat completions (streaming and non-streaming)

  • POST /v1/embeddings — embeddings

  • GET /v1/models — model list

Streaming uses SSE (Server-Sent Events) with data: [DONE] as the end marker. Passthrough format name is openai, forwarding to https://api.openai.com when passthrough is enabled.

SEE ALSO

SUPPORT

Issues

Please report bugs and feature requests on GitHub at https://github.com/Getty/langertha-knarr/issues.

CONTRIBUTING

Contributions are welcome! Please fork the repository and submit a pull request.

AUTHOR

Torsten Raudssus <torsten@raudssus.de> https://raudssus.de/

COPYRIGHT AND LICENSE

This software is copyright (c) 2026 by Torsten Raudssus.

This is free software; you can redistribute it and/or modify it under the same terms as the Perl 5 programming language system itself.