NAME

Langertha::Knarr::CLI - CLI entry point for Knarr LLM Proxy

VERSION

version 0.004

DESCRIPTION

MooX::Cmd entry point for the knarr CLI. Dispatches to subcommand classes under Langertha::Knarr::CLI::Cmd::*. When invoked without a subcommand, prints a banner and usage summary.

For full CLI documentation see knarr and Langertha::Knarr.

SEE ALSO

--config

Path to the YAML configuration file. Short form: -c. Defaults to ./knarr.yaml. Applies to all subcommands.

--verbose

Enable verbose logging to stderr. Short form: -v. Applies to all subcommands.

SUPPORT

Issues

Please report bugs and feature requests on GitHub at https://github.com/Getty/langertha-knarr/issues.

CONTRIBUTING

Contributions are welcome! Please fork the repository and submit a pull request.

AUTHOR

Torsten Raudssus <torsten@raudssus.de> https://raudssus.de/

COPYRIGHT AND LICENSE

This software is copyright (c) 2026 by Torsten Raudssus.

This is free software; you can redistribute it and/or modify it under the same terms as the Perl 5 programming language system itself.